@@ -3,12 +3,12 @@ from __future__ import absolute_import
 from __future__ import division
 
 import sys
+import compas
 
 try:
     import System
 except ImportError:
-    if 'ironpython' in sys.version.lower():
-        raise
+    compas.raise_if_ironpython()
 
 
 __all__ = ['MatlabClient']
