@@ -52,6 +52,8 @@ be used for the representation of subdivided/partitioned polyhedra.
 
 """
 
+from __future__ import absolute_import
+from __future__ import division
 from __future__ import print_function
 
 
@@ -63,8 +65,4 @@ from .network import *
 from .mesh import *
 from .volmesh import *
 
-from .network import __all__ as a
-from .mesh import __all__ as c
-from .volmesh import __all__ as d
-
-__all__ = a + c + d
+__all__ = [name for name in dir() if not name.startswith('_')]
