@@ -23,6 +23,9 @@ from compas.geometry import centroid_points
 from compas.geometry import centroid_polygon
 from compas.geometry import cross_vectors
 from compas.geometry import length_vector
+from compas.geometry import scale_vector
+from compas.geometry import add_vectors
+from compas.geometry import sum_vectors
 from compas.geometry import subtract_vectors
 from compas.geometry import normal_polygon
 from compas.geometry import area_polygon
@@ -113,8 +116,8 @@ class Mesh(FromToPickle,
         mesh = Mesh.from_obj(compas.get('faces.obj'))
 
         mesh.plot(
-            vertextext={key: key for key in network.vertices()},
-            vertexcolor={key: '#ff0000' for key in mesh.vertices_where({'vertex_degree': 2})}
+            vertextext={key: key for key in mesh.vertices()},
+            vertexcolor={key: '#ff0000' for key in mesh.vertices_where({'vertex_degree': 2})},
             vertexsize=0.2
         )
 
@@ -1575,17 +1578,15 @@ class Mesh(FromToPickle,
                 edges.add((u, v))
                 edges.add((v, u))
 
-                if (u, v) not in self.edgedata:
-                    self.edgedata[u, v] = self.default_edge_attributes.copy()
-
-                    if (v, u) in self.edgedata:
-                        self.edgedata[u, v].update(self.edgedata[v, u])
-                        del self.edgedata[v, u]
-
-                    self.edgedata[v, u] = self.edgedata[u, v]
+                if (u, v) in self.edgedata:
+                    attr = self.edgedata[v, u] = self.edgedata[u, v]
+                elif (v, u) in self.edgedata:
+                    attr = self.edgedata[u, v] = self.edgedata[v, u]
+                else:
+                    attr = self.edgedata[u, v] = self.edgedata[v, u] = self.default_edge_attributes.copy()
 
                 if data:
-                    yield u, v, self.edgedata[u, v]
+                    yield u, v, attr
                 else:
                     yield u, v
 
@@ -2298,7 +2299,7 @@ class Mesh(FromToPickle,
             The area.
         """
 
-        return sum([self.face_area(fkey) for fkey in self.faces()])
+        return sum(self.face_area(fkey) for fkey in self.faces())
 
     def centroid(self):
         """Calculate the mesh centroid.
@@ -2311,8 +2312,16 @@ class Mesh(FromToPickle,
         list
             The coordinates of the mesh centroid.
         """
-
-        return scale_vector(1. / self.area(), add_vectors([scale_vector(self.face_area(fkey), self.face_centroid(fkey)) for fkey in mesh.faces()]))
+        A = 0
+        cx, cy, cz = 0.0, 0.0, 0.0
+        for fkey in self.faces():
+            a = self.face_area(fkey)
+            x, y, z = self.face_centroid(fkey)
+            cx += a * x
+            cy += a * y
+            cz += a * z
+            A += a
+        return [cx / A, cy / A, cz / A]
 
     def normal(self):
         """Calculate the average mesh normal.
@@ -2326,7 +2335,7 @@ class Mesh(FromToPickle,
             The coordinates of the mesh normal.
         """
 
-        return scale_vector(1. / self.area(), add_vectors([scale_vector(self.face_area(fkey), self.face_normal(fkey)) for fkey in mesh.faces()]))
+        return scale_vector(1. / self.area(), add_vectors([scale_vector(self.face_area(fkey), self.face_normal(fkey)) for fkey in self.faces()]))
 
     # --------------------------------------------------------------------------
     # vertex geometry
@@ -3035,6 +3044,8 @@ if __name__ == '__main__':
 
     mesh = Mesh.from_obj(compas.get('faces.obj'))
 
+    mesh.update_default_edge_attributes({'q': 1.0})
+
     # vertices = [
     #     [0, 0, 0],
     #     [1, 1, 0],
@@ -3064,10 +3075,13 @@ if __name__ == '__main__':
 
     # # mesh.add_face([a, b, c, d, e, f, g, h])
 
-    for k in mesh.face:
+    for k in mesh.faces():
         print(k, mesh.is_face_on_boundary(k))
 
 
+    print(list(mesh.edges(True)))
+
+
     plotter = MeshPlotter(mesh)
 
     plotter.draw_vertices()
