@@ -8,7 +8,8 @@ from compas.geometry import centroid_points
 from compas.geometry import distance_point_point
 from compas.geometry import distance_line_line
 
-from compas.geometry.algorithms.bestfit import bestfit_plane
+from compas.geometry.algorithms import bestfit_plane
+# from compas.geometry.algorithms import bestfit_plane_numpy
 
 from compas.utilities import window
 
@@ -130,6 +131,72 @@ def planarize_faces(vertices,
             callback(k, callback_args)
 
 
+# def planarize_faces_numpy(vertices,
+#                           faces,
+#                           fixed=None,
+#                           kmax=100,
+#                           callback=None,
+#                           callback_args=None):
+#     """Planarise a set of connected faces.
+
+#     Planarisation is implemented as a two-step iterative procedure. At every
+#     iteration, faces are first individually projected to their best-fit plane,
+#     and then the vertices are projected to the centroid of the disconnected
+#     corners of the faces.
+
+#     Parameters
+#     ----------
+#     vertices : list
+#         The vertex coordinates.
+#     faces : list
+#         The vertex indices per face.
+#     fixed : list, optional [None]
+#         A list of fixed vertices.
+#     kmax : int, optional [100]
+#         The number of iterations.
+#     callback : callable, optional [None]
+#         A user-defined callback that is called after every iteration.
+#     callback_args : list, optional [None]
+#         A list of arguments to be passed to the callback function.
+
+#     See Also
+#     --------
+#     * :func:`compas.geometry.mesh_planarize_faces`
+#     * :func:`compas.geometry.mesh_planarize_faces_shapeop`
+
+#     """
+#     if callback:
+#         if not callable(callback):
+#             raise Exception('The callback is not callable.')
+
+#     fixed = fixed or []
+#     fixed = set(fixed)
+
+#     for k in range(kmax):
+
+#         positions = [[] for _ in range(len(vertices))]
+
+#         for face in iter(faces):
+#             points = [vertices[index] for index in face]
+#             plane = bestfit_plane_numpy(points)
+#             projections = project_points_plane(points, plane)
+
+#             for i, index in enumerate(face):
+#                 positions[index].append(projections[i])
+
+#         for index, vertex in enumerate(vertices):
+#             if index in fixed:
+#                 continue
+
+#             x, y, z = centroid_points(positions[index])
+#             vertex[0] = x
+#             vertex[1] = y
+#             vertex[2] = z
+
+#         if callback:
+#             callback(k, callback_args)
+
+
 # ==============================================================================
 # mesh variations
 # ==============================================================================
