@@ -287,7 +287,7 @@ def voronoi_from_points_numpy(points):
         plotter.draw_arrows(arrows)
         plotter.draw_vertices(radius=0.02)
         plotter.draw_faces()
-        plotter.show()    
+        plotter.show()
 
     """
     from numpy import asarray
@@ -647,98 +647,159 @@ def trimesh_remesh(mesh,
 
 if __name__ == "__main__":
 
-    testrun = 2
+    import compas
+    import os
+    from compas.datastructures import Mesh
+    from compas.plotters import MeshPlotter
+    from compas.utilities import pairwise
 
-    if testrun == 1:
-        from compas.datastructures import Mesh
-        from compas.geometry import pointcloud_xy
-        from compas.plotters import MeshPlotter
+    from triangle import triangulate
 
-        points = pointcloud_xy(10, (0, 10))
-        faces = delaunay_from_points(points)
-        mesh = Mesh.from_vertices_and_faces(points, faces)
+    points = [
+        [2.994817685045075, 10.855606612493078, 0.0],
+        [4.185204599300653, 9.527867361977242, 0.0],
+        [4.414125159734419, 10.718254276232818, 0.0],
+        [5.925000858597267, 9.344730913630228, 0.0],
+        [8.900968144236211, 10.809822500406325, 0.0],
+        [9.496161601363999, 8.566401008155429, 0.0],
+        [7.710581229980631, 7.9254234389408875, 0.0],
+        [7.847933566240888, 6.414547740078039, 0.0],
+        [3.9104999267801377, 4.9036720412151915, 0.0],
+        [5.2909301507195865, 6.342692886748852, 0.0]
+    ]
 
-        trimesh_remesh(mesh, 1.0, kmax=300, allow_boundary_split=True)
+    points = [
+        [0.0, 0.0, 0.0],
+        [1.0, 0.0, 0.0],
+        [1.0, 1.0, 0.0],
+        [2.0, 1.0, 0.0],
+        [3.0, 1.0, 0.0],
+        [4.0, 1.0, 0.0],
+        [5.0, 1.0, 0.0],
+        [6.0, 1.0, 0.0],
+        [7.0, 1.0, 0.0],
+        [8.0, 1.0, 0.0],
+        [9.0, 1.0, 0.0],
+        [10.0, 1.0, 0.0],
+        [10.0, 0.0, 0.0],
+        [11.0, 0.0, 0.0],
+        [11.0, 1.0, 0.0],
+        [10.5, 1.0, 0.0],
+        [10.5, 2.0, 0.0],
+        [5.5, 2.0, 0.0],
+        [0.5, 2.0, 0.0],
+        [0.5, 1.0, 0.0],
+        [0.0, 1.0, 0.0]
+    ]
 
-        points = [mesh.vertex_coordinates(key) for key in mesh.vertices()]
+    data = {
+        'vertices': [point[0:2] for point in points],
+        'segments': list(pairwise(list(range(len(points))) + [0]))
+    }
 
-        faces = delaunay_from_points(points)
-        mesh = Mesh.from_vertices_and_faces(points, faces)
+    res = triangulate(data, opts='p')
 
-        voronoi  = voronoi_from_delaunay(mesh)
+    faces = res['triangles']
 
-        lines = []
-        for u, v in voronoi.edges():
-            lines.append({
-                'start': voronoi.vertex_coordinates(u, 'xy'),
-                'end'  : voronoi.vertex_coordinates(v, 'xy'),
-                'width': 1.0
-            })
+    mesh = Mesh.from_vertices_and_faces(points, faces)
 
-        plotter = MeshPlotter(mesh, figsize=(10, 7))
+    plotter = MeshPlotter(mesh)
+    plotter.draw_faces()
+    plotter.draw_vertices(text='key')
+    plotter.save(os.path.join(compas.TEMP, 'anjali.png'))
 
-        plotter.draw_lines(lines)
+    # testrun = 2
 
-        plotter.draw_vertices(
-            radius=0.075,
-            facecolor={key: '#0092d2' for key in mesh.vertices() if key not in mesh.vertices_on_boundary()})
+    # if testrun == 1:
+    #     from compas.datastructures import Mesh
+    #     from compas.geometry import pointcloud_xy
+    #     from compas.plotters import MeshPlotter
 
-        plotter.draw_edges(color='#cccccc')
+    #     points = pointcloud_xy(10, (0, 10))
+    #     faces = delaunay_from_points(points)
+    #     mesh = Mesh.from_vertices_and_faces(points, faces)
 
-        plotter.show()
+    #     trimesh_remesh(mesh, 1.0, kmax=300, allow_boundary_split=True)
 
-    if testrun == 2:
-        from compas.datastructures import Mesh
-        from compas.plotters import MeshPlotter
-        from compas.geometry import mesh_smooth_area
+    #     points = [mesh.vertex_coordinates(key) for key in mesh.vertices()]
 
-        vertices = [(0.0, 0.0, 0.0), (10.0, 0.0, 0.0), (10.0, 10.0, 0.0), (0.0, 10.0, 0.0)]
-        faces = [[0, 1, 2, 3]]
+    #     faces = delaunay_from_points(points)
+    #     mesh = Mesh.from_vertices_and_faces(points, faces)
 
-        mesh = Mesh.from_vertices_and_faces(vertices, faces)
+    #     voronoi  = voronoi_from_delaunay(mesh)
 
-        key = mesh.insert_vertex(0)
-        fixed = [key]
+    #     lines = []
+    #     for u, v in voronoi.edges():
+    #         lines.append({
+    #             'start': voronoi.vertex_coordinates(u, 'xy'),
+    #             'end'  : voronoi.vertex_coordinates(v, 'xy'),
+    #             'width': 1.0
+    #         })
 
-        plotter = MeshPlotter(mesh, figsize=(10, 7))
+    #     plotter = MeshPlotter(mesh, figsize=(10, 7))
 
-        plotter.draw_edges(width=0.5)
+    #     plotter.draw_lines(lines)
 
-        def callback(mesh, k, args):
-            print(k)
-            plotter.update_edges()
-            plotter.update()
+    #     plotter.draw_vertices(
+    #         radius=0.075,
+    #         facecolor={key: '#0092d2' for key in mesh.vertices() if key not in mesh.vertices_on_boundary()})
 
-        trimesh_remesh(
-            mesh,
-            1.0,
-            kmax=200,
-            allow_boundary_split=True,
-            allow_boundary_swap=True,
-            allow_boundary_collapse=False,
-            fixed=fixed,
-            callback=callback)
+    #     plotter.draw_edges(color='#cccccc')
 
-        mesh_smooth_area(mesh, fixed=mesh.vertices_on_boundary())
+    #     plotter.show()
 
-        plotter.update_edges()
-        plotter.update(pause=2.0)
-        plotter.show()
+    # if testrun == 2:
+    #     from compas.datastructures import Mesh
+    #     from compas.plotters import MeshPlotter
+    #     from compas.geometry import mesh_smooth_area
 
-    if testrun == 3:
-        from compas.geometry import pointcloud_xy
-        from compas.datastructures import Mesh
-        from compas.topology import delaunay_from_points
-        from compas.plotters import MeshPlotter
+    #     vertices = [(0.0, 0.0, 0.0), (10.0, 0.0, 0.0), (10.0, 10.0, 0.0), (0.0, 10.0, 0.0)]
+    #     faces = [[0, 1, 2, 3]]
 
-        points = pointcloud_xy(10, (0, 10))
-        faces = delaunay_from_points(points)
+    #     mesh = Mesh.from_vertices_and_faces(vertices, faces)
 
-        delaunay = Mesh.from_vertices_and_faces(points, faces)
+    #     key = mesh.insert_vertex(0)
+    #     fixed = [key]
 
-        plotter = MeshPlotter(delaunay)
+    #     plotter = MeshPlotter(mesh, figsize=(10, 7))
 
-        plotter.draw_vertices(radius=0.1)
-        plotter.draw_faces()
+    #     plotter.draw_edges(width=0.5)
 
-        plotter.show()
+    #     def callback(mesh, k, args):
+    #         print(k)
+    #         plotter.update_edges()
+    #         plotter.update()
+
+    #     trimesh_remesh(
+    #         mesh,
+    #         1.0,
+    #         kmax=200,
+    #         allow_boundary_split=True,
+    #         allow_boundary_swap=True,
+    #         allow_boundary_collapse=False,
+    #         fixed=fixed,
+    #         callback=callback)
+
+    #     mesh_smooth_area(mesh, fixed=mesh.vertices_on_boundary())
+
+    #     plotter.update_edges()
+    #     plotter.update(pause=2.0)
+    #     plotter.show()
+
+    # if testrun == 3:
+    #     from compas.geometry import pointcloud_xy
+    #     from compas.datastructures import Mesh
+    #     from compas.topology import delaunay_from_points
+    #     from compas.plotters import MeshPlotter
+
+    #     points = pointcloud_xy(10, (0, 10))
+    #     faces = delaunay_from_points(points)
+
+    #     delaunay = Mesh.from_vertices_and_faces(points, faces)
+
+    #     plotter = MeshPlotter(delaunay)
+
+    #     plotter.draw_vertices(radius=0.1)
+    #     plotter.draw_faces()
+
+    #     plotter.show()
