@@ -31,7 +31,7 @@ from .utilities import *
 from . import utilities
 
 
-__version__ = '0.3.5'
+__version__ = '0.3.6'
 
 
 PURGE_ON_DELETE = True
@@ -58,5 +58,4 @@ def _get_ironpython_lib_path(version):
     return ironpython_lib_path
 
 
-__all__  = ['__version__', 'PURGE_ON_DELETE']
-__all__ += utilities.__all__
+__all__ = [name for name in dir() if not name.startswith('_')]
