@@ -24,9 +24,4 @@ from .meshartist import *
 from .networkartist import *
 from .volmeshartist import *
 
-from . import artist
-from . import meshartist
-from . import networkartist
-from . import volmeshartist
-
-__all__ = artist.__all__ + meshartist.__all__ + networkartist.__all__ + volmeshartist.__all__
+__all__ = [name for name in dir() if not name.startswith('_')]
