@@ -155,20 +155,4 @@ from .drawing import *
 from .geometry import *
 from .xfunc import *
 
-from . import document
-from . import layers
-from . import objects
-from . import misc
-from . import drawing
-from . import geometry
-from . import xfunc
-
-__all__ = []
-
-__all__ += document.__all__
-__all__ += layers.__all__
-__all__ += objects.__all__
-__all__ += misc.__all__
-__all__ += drawing.__all__
-__all__ += geometry.__all__
-__all__ += xfunc.__all__
+__all__ = [name for name in dir() if not name.startswith('_')]
